@@ -1,6 +1,6 @@
 package OpenID::Login;
 {
-  $OpenID::Login::VERSION = '0.1.1';
+  $OpenID::Login::VERSION = '0.1.2';
 }
 
 # ABSTRACT: A simple lightweight OpenID consumer with very few dependencies
@@ -159,8 +159,7 @@ sub verify_auth {
     my $param_claimed_id = $self->_get_param('openid.claimed_id');
     if ( !$claimed_id ) {
         $self->claimed_id($param_claimed_id);
-    }
-    elsif ( $claimed_id ne $param_claimed_id ) {
+    } elsif ( $claimed_id ne $param_claimed_id ) {
         carp "Identity from parameters ($param_claimed_id) is not the same as the previously set claimed identity ($claimed_id); using the parameter version.";
         $self->claimed_id($param_claimed_id);
     }
@@ -179,10 +178,6 @@ sub verify_auth {
 
     my $ua = $self->ua;
 
-    open RESOUT, '>>/var/log/shop_openid_login';
-    print RESOUT `date` . "VERIFY: " . $verify_endpoint . "\n";
-    close RESOUT;
-
     my $response = $ua->get( $verify_endpoint, Accept => 'text/plain' );
     my $response_data = _parse_direct_response($response);
 
@@ -237,20 +232,16 @@ sub _get_param {
     if ( my $cgi = $self->cgi ) {
         if ($param) {
             return $cgi->param($param);
-        }
-        else {
+        } else {
             return $cgi->param();
         }
-    }
-    elsif ( my $cgi_params = $self->cgi_params ) {
+    } elsif ( my $cgi_params = $self->cgi_params ) {
         if ($param) {
             return $cgi_params->{$param};
-        }
-        else {
+        } else {
             return keys %$cgi_params;
         }
-    }
-    else {
+    } else {
         croak('Neither cgi nor cgi_params attributes have been provided (needed to verify OpenID parameters)');
     }
 }
@@ -269,7 +260,7 @@ OpenID::Login - A simple lightweight OpenID consumer with very few dependencies
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
@@ -372,7 +363,7 @@ Holger Eiboeck <realholgi@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Holger Eiboeck.
+This software is copyright (c) 2013 by Holger Eiboeck.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
